@@ -10,15 +10,6 @@
 #![deny(clippy::unimplemented)]
 #![deny(clippy::missing_safety_doc)]
 
-// Primarily used for debug purposes.
-cfg_if::cfg_if! {
-    if #[cfg(feature = "log")] {
-        #[allow(unused_imports)]
-        #[macro_use]
-        extern crate log;
-    }
-}
-
 use std::{
     boxed::Box,
     fs,
@@ -56,19 +47,21 @@ use utils::error;
 
 pub mod app;
 pub mod utils {
+    pub mod data_units;
     pub mod error;
     pub mod gen_util;
     pub mod logging;
 }
+pub mod args;
 pub mod canvas;
-pub mod clap;
 pub mod components;
 pub mod constants;
 pub mod data_conversion;
 pub mod options;
-pub mod units;
 pub mod widgets;
 
+pub use utils::logging::*;
+
 #[cfg(target_family = "windows")]
 pub type Pid = usize;
 
@@ -117,7 +110,7 @@ pub fn handle_mouse_event(event: MouseEvent, app: &mut App) {
 pub fn handle_key_event_or_break(
     event: KeyEvent, app: &mut App, reset_sender: &Sender<CollectionThreadEvent>,
 ) -> bool {
-    // debug!("KeyEvent: {:?}", event);
+    // c_debug!("KeyEvent: {:?}", event);
 
     if event.modifiers.is_empty() {
         // Required catch for searching - otherwise you couldn't search with q.
@@ -154,8 +147,6 @@ pub fn handle_key_event_or_break(
                 KeyCode::Char('c') | KeyCode::Char('C') => app.toggle_ignore_case(),
                 KeyCode::Char('w') | KeyCode::Char('W') => app.toggle_search_whole_word(),
                 KeyCode::Char('r') | KeyCode::Char('R') => app.toggle_search_regex(),
-                // KeyCode::Char('b') | KeyCode::Char('B') => todo!(),
-                // KeyCode::Char('f') | KeyCode::Char('F') => todo!(),
                 KeyCode::Char('h') => app.on_left_key(),
                 KeyCode::Char('l') => app.on_right_key(),
                 _ => {}
@@ -493,7 +484,7 @@ pub fn create_collection_thread(
     let use_current_cpu_total = app_config_fields.use_current_cpu_total;
     let unnormalized_cpu = app_config_fields.unnormalized_cpu;
     let show_average_cpu = app_config_fields.show_average_cpu;
-    let update_time = app_config_fields.update_rate_in_milliseconds;
+    let update_time = app_config_fields.update_rate;
 
     thread::spawn(move || {
         let mut data_state = data_harvester::DataCollector::new(filters);
